@@ -12,8 +12,23 @@ Postprocess.R2GUESS <- function(x){
   Namefeatures <- file.path(x$path.output, paste(x$root.file.output,"features.txt",sep="_"))
   features <- read.table(file=Namefeatures,header=TRUE)
   rownames(features) <- features[,1]
-  
-  
+
+
+history.file <- file.path(
+    x$path.output, paste(x$root.file.output, "output_models_history.txt", sep="_"))
+model.history <- read.table(history.file, header=FALSE, sep="\t",
+                            skip=x$burn.in + 1, stringsAsFactors=FALSE)
+mppi.mc <- tabulate(
+    as.integer(c(lapply(model.history[,5], strsplit, split=" ", fixed=TRUE),
+               recursive=TRUE)),
+    nbins=x$p
+) / features["last_sweep","value"]
+mppi.file <- file.path(
+    x$path.output, paste(x$root.file.output, "output_marg_prob_incl_mc.txt", sep="_"))
+write.table(mppi.mc, mppi.file, quote=FALSE, sep="\t",
+            col.names=c("Predictor\tMarg_Prob_Incl"))
+
+
   BestModels <- get.best.models(x$path.output,x$path.input,x$root.file.output,label.X=x$label.X,p=x$p,x$MAP.file)
   res <- list(dataY = x$dataY, dataX = x$dataX, path.input = x$path.input, 
               path.output = x$path.output, path.par=x$path.par, path.init=x$path.init, history = x$history, time = x$time, file.par =x$file.par,file.init=x$file.init,file.log=x$file.log,
